@@ -666,8 +666,7 @@ class Database(object):
         :rtype: `ViewResults`
         """
         return TemporaryView(uri(self.resource.uri, '_temp_view'), map_fun,
-                             reduce_fun, language=language, wrapper=wrapper,
-                             curl=self.resource.curl)(**options)
+                             reduce_fun, language=language, wrapper=wrapper)(**options)
 
     def update(self, documents, **options):
         """Perform a bulk update or insertion of the given documents using a
@@ -867,7 +866,7 @@ class Document(dict):
         else:
             raise Exception('Can\'t delete document - target database is undefined')
 
-    def create(self, id, suffix_length = 12, max_retry = 100, db = None):
+    def create(self, id, suffix_length = 12, max_retry = 100, db = None, force_random_suffix=False):
         """Conflict-safe document creator.
         Document id will be '<id>' or '<id><random suffix>' if '<id>' already exists.
         
@@ -879,7 +878,11 @@ class Document(dict):
         id_string = '%s%s'
         db = db or getattr(self, '_db', None)
         if db:
-            doc_id = id_string % (id, '')
+            rand = ''
+            if force_random_suffix:
+                rand = hashlib.sha1(str(random.random())).hexdigest()[:suffix_length]
+                
+            doc_id = id_string % (id, rand)
             
             while True:
                 
@@ -896,9 +899,6 @@ class Document(dict):
                 rand = hashlib.sha1(str(random.random())).hexdigest()[:suffix_length]
                 doc_id = id_string % (id, '_%s' % rand)
             
-            #self['_id'] = data['_id']
-            #self['_rev'] = data['_rev']
-            
         else:
             raise Exception('Can\'t create document - target database is undefined')
         
@@ -982,8 +982,8 @@ class TemporaryView(View):
     """Representation of a temporary view."""
 
     def __init__(self, uri, map_fun, reduce_fun=None,
-                 language='javascript', wrapper=None, curl=None):
-        View.__init__(self, uri, wrapper=wrapper, curl=curl)
+                 language='javascript', wrapper=None):
+        View.__init__(self, uri, wrapper=wrapper)
         if isinstance(map_fun, FunctionType):
             map_fun = getsource(map_fun).rstrip('\n\r')
         self.map_fun = dedent(map_fun.lstrip('\n\r'))
@@ -1203,7 +1203,6 @@ class Resource(object):
 
     def _request(self, method, path=None, content=None, headers=None,
                  **params):
-
         def _make_request(curl, path, params, body, retry = 1):
             
             stringbuf = StringIO()
@@ -1237,7 +1236,6 @@ class Resource(object):
         
 
         from couchdbcurl import __version__
-
         curl = pycurl.Curl()
         
         ## if method in ("PUT", "POST"):
